.. aiotaika documentation master file, created by
   sphinx-quickstart on Fri Apr 14 14:00:07 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to aiotaika's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   aiotaika
   installation
   examples
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
